#
# spec file for package amtu
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sfprj amtueal
Name:           amtu
URL:            https://sourceforge.net/projects/amtueal/
Requires:       audit >= 1.2.9
Version:        1.0.8
Release:        29.2
Summary:        Abstract Machine Test Utility
License:        CPL-1.0
Group:          Productivity/Security
Source:         https://downloads.sourceforge.net/%{sfprj}/%{name}-%{version}.tar.gz
Patch0:         amtu-1.0.8_memsep_fclose_bnc523353.diff
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  audit
BuildRequires:  audit-devel
BuildRequires:  audit-libs
ExclusiveArch:  %ix86 x86_64 ia64 ppc ppc64 s390 s390x

%description
Abstract Machine Test Utility (AMTU) is an administrative utility to
check whether the underlying protection mechanism of the hardware is
still being enforced. This is a requirement of the Controlled Access
Protection Profile (CAPP) FTP_AMT.1. See
http://www.radium.csc.mil/tpep/library/protection_profiles/CAPP-1.d.pdf
.

%prep
%autosetup -p1 amtu

%build
CFLAGS="$RPM_OPT_FLAGS -D_GNU_SOURCE -Wall -pipe -fcommon"
    CC=gcc
export CC CFLAGS
  ./configure                           \
	--prefix=/usr			\
	--bindir=/usr/sbin		\
	--mandir=%{_mandir}
  make %{?_smp_mflags}

%install
mkdir -p $RPM_BUILD_ROOT/%{_defaultdocdir}/amtu
make DESTDIR=$RPM_BUILD_ROOT install-strip
install -m 644 doc/amtu.8    $RPM_BUILD_ROOT/%{_mandir}/man8/amtu.8

%files
%defattr(-,root,root)
%attr(700,root,root)/usr/sbin/amtu
%doc %attr(444,root,root) %{_mandir}/man8/amtu.8*
%doc %attr(755,root,root) %{_defaultdocdir}/amtu

%changelog
* Fri Apr  5 2024 Atri Bhattacharya <badshah400@gmail.com>
- Use full URL for source.
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Thu May 19 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Use https:// url (http:// redirects to it anyway).
* Thu Jun 11 2020 Paolo Stivanin <info@paolostivanin.com>
- Add -fcommon to allow package to build with GCC10
* Tue Mar  6 2012 aj@suse.de
- Remove obsolete suse_update_config call
- No need to run bootstrap, the automake etc files are good enough
- Cleanup spec file
* Fri Dec  2 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Thu Feb  4 2010 jengelh@medozas.de
- add ExclusiveArch to specfile, as the package only has source
  files for certain architectures and fails on SPARC.
* Fri Jul 24 2009 thomas@novell.com
- fixed %%files section in spec file by adding %%doc
* Thu Jul 23 2009 thomas@novell.com
- upgraded to version 1.0.8
- added patch for missing fclose() in src/memsep.c (bnc#523353)
* Fri Mar  2 2007 ro@suse.de
- fix buildreq
* Tue Feb 27 2007 draht@suse.de
- port from sles9 tree to sle10-sp for SP1, initial package in
  CODE10
- version upgrade to 1.0.4; featuring audit (LAF) support for
  compliance with CAPP
* Mon Sep  6 2004 thomas@suse.de
- added laus, laus-devel to needforbuild
* Thu Aug 26 2004 thomas@suse.de
- added patch to make memory separation testcase work on
  machines with kernel f_pos race fix. it is needed due to
  new permissions on /proc/self/maps.
* Fri Aug 20 2004 thomas@suse.de
- created initial package for EAL4 evaluation of SLES9
